diff --git a/modules/system/system.api.php b/modules/system/system.api.php
index 6faa6afb6a3cb17ebbe6d59f3b13e892c2ede470..e2dbfdc90ab13c1da4ada0cd05968a11cfadfd28 100644
--- a/modules/system/system.api.php
+++ b/modules/system/system.api.php
@@ -3283,8 +3283,8 @@ function hook_token_info_alter(&$data) {
  * @see _country_get_predefined_list()
  */
 function hook_countries_alter(&$countries) {
-  // Quebec has seceded from Canada. Add to country list.
-  $countries['QC'] = 'Quebec';
+  // Elbonia is now independent, so add it to the country list.
+  $countries['EB'] = 'Elbonia';
 }
 
 /**